@@ -50,16 +50,16 @@ setClass(".Rotation",
 setMethod("initialize", "BasicRaster",
 	function(.Object, ..., crs=NA, srs="") {
 		.Object <- callNextMethod(.Object, ...)
-		if (!is.na(crs)) {
+		if ((length(crs) > 0) && (!isTRUE(is.na(crs)))) {
 			if (.hasSlot(.Object, "srs")) {
 				.Object@srs <- .getSRS(crs)
 			}
-			.Object@crs <- crs
+			#.Object@crs <- crs
 		} else if (srs != "") {
 			if (.hasSlot(.Object, "srs")) {
 				.Object@srs <- .getSRS(srs)
 			}
-			.Object@crs <- .makeCRS(srs)
+			#.Object@crs <- .makeCRS(srs)
 		}
 		.Object
 	}
@@ -83,6 +83,7 @@ setClass ("BasicRaster",
 	),
 	prototype (	
 		crs = sp::CRS(doCheckCRSArgs=FALSE),
+		srs = "",
 		rotated = FALSE,
 		ncols= as.integer(1),
 		nrows= as.integer(1),
